<template>
  <NutForm
    :model-value="form"
    ref="formRef"
    :rules="rules"
    label-position="top"
    class="order-bill-recharge electric"
  >
    <NutFormItem class="bole-form-item" prop="currentUserAccountId">
      <NutRadioGroup
        v-model="form.currentUserAccountId"
        direction="horizontal"
        class="par-account-list"
        v-if="userAccountAllList.length > 0"
        @change="handleUserAccountChange"
      >
        <NutRadio :label="item.id" shape="button" v-for="item in userAccountAllList" :key="item.id"
          >{{ item.city }}-{{ item.content }}</NutRadio
        >
      </NutRadioGroup>
      <AccountCard
        v-if="userAccountAllList.length > 0"
        title="充值户号"
        :content="`${form.areaList?.[1] ?? ''} ${form.gasAccount}`"
        :remark="form.remark"
      >
        <template #action>
          <div class="account-card-action" @click="handleAddUserAccount">新增</div>
        </template>
      </AccountCard>
      <AccountAddCard text="新增户号" v-else @click="handleAddUserAccount" />
    </NutFormItem>

    <NutFormItem label="选择充值金额" class="bole-form-item" prop="parValue" required>
      <NutRadioGroup v-model="form.parValue" direction="horizontal" class="parValue-radio-group">
        <NutRadio
          :label="Number(item)"
          :key="item"
          shape="button"
          v-for="item in gasValueList"
          class="parValue-item"
        >
          <div class="parValue-item-inner">
            <div class="amount-wrapper">
              <div class="amount">{{ item }}</div>
              <div class="unit">元</div>
            </div>
            <div class="price-wrapper">
              <div class="price-text">折后</div>
              <div class="price">
                {{ blLifeRecharge.getRechargeParValue(item, lifePayGasRate) }}元
              </div>
            </div>
            <div class="discountTag">{{ lifePayGasRate }}折</div>
          </div>
        </NutRadio>
      </NutRadioGroup>
    </NutFormItem>
    <SelectPayTypeFormItem
      v-model="form.lifePayType"
      :showWeixinPay="showWeixinPay"
      :showAliPay="showAliPay"
    ></SelectPayTypeFormItem>
    <div class="common-content">
      <nut-button class="recharge-button" type="primary" @click="handleSubmit">
        <div class="recharge-button-inner">
          <div>￥{{ realParValue }}</div>
          <div class="recharge-button-text">立即充值</div>
        </div>
      </nut-button>
      <RechargeTipsView :lifePayOrderType="LifeRechargeConstants.LifePayOrderTypeEnum.燃气订单">
        <template #tips-top>
          同一电费账户在充值期间切勿在多平台重复充值，下单前请仔细阅读下方须知内容。若接到陌生来电，切勿轻信！！！
        </template>
      </RechargeTipsView>
    </div>
    <ConfirmDialog v-model:visible="confirmDialogVisible" @ok="goPay">
      <template #tips>
        该产品为慢充模式，0-72小时内到账，介意请勿付款！充值前请仔细阅读充值须知！
      </template>
      <template #info>
        <ConfirmDialogInfoItem
          label="燃气类型"
          :content="currentGasParValueItem?.gasOrgName ?? ''"
        />
        <ConfirmDialogInfoItem :label-width="96" label="户号" :content="form.gasAccount" />
        <ConfirmDialogInfoItem label="充值金额" :content="`￥${form.parValue.toFixed(2)}`" danger />
        <ConfirmDialogInfoItem label="优惠金额" :content="`￥${discountParValue.toFixed(2)}`" />
        <ConfirmDialogInfoItem label="实付金额" :content="`￥${realParValue}`" danger />
      </template>
      <template #warning>
        同一燃气费账户在充值期间，未到账前切勿在其他任何平台再次充值。因此造成的资金损失须用户自行承担！！！
      </template>
    </ConfirmDialog>
    <NutToast :msg="state.msg" v-model:visible="state.show" type="warn" cover />
  </NutForm>
</template>

<script setup lang="ts">
import {
  Form as NutForm,
  FormItem as NutFormItem,
  RadioGroup as NutRadioGroup,
  Radio as NutRadio,
  Button as NutButton,
  Toast as NutToast,
} from '@nutui/nutui-taro';
import { FormRules } from '@nutui/nutui-taro/dist/types/__VUE/form/types';
import { reactive, ref, computed, toRef } from 'vue';
import {
  useLifeRechargeContext,
  LifeElectricDataCreateLifePayOrderInput,
  LifeRechargeConstants,
  LifeGasDataCreateLifePayOrderInput,
} from '@life-payment/core-vue';
import { useGetRate, useGetGasParValue, useSetUserAccountBySelect } from '../../hooks';
import { useGasBillRechargeContext, GasUserAccountExtraProperties } from './context';
import { FormValidator, initLifePayType } from '../../utils';
import AccountAddCard from '../../components/Card/AccountAddCard.vue';
import AccountCard from '../../components/Card/AccountCard.vue';
import RechargeTipsView from '../../components/RechargeTipsView/RechargeTipsView.vue';
import ConfirmDialog from '../../components/Dialog/ConfirmDialog.vue';
import ConfirmDialogInfoItem from '../../components/Dialog/ConfirmDialogInfoItem.vue';
import SelectPayTypeFormItem from '../../components/SelectPayTypeFormItem/SelectPayTypeFormItem.vue';
import { useSelectPayType, useGetPayStatusByOrderNo } from '../../hooks/selectPayType';
import { RechargeProps } from '../PhoneBillRecharge/types';

defineOptions({
  name: 'GasBillRechargeStep3',
});

const props = withDefaults(defineProps<RechargeProps>(), {
  isDev: false,
});

const emit = defineEmits<{
  (e: 'goPay', orderNo: string): void;
  (e: 'paySuccess', orderNo: string): void;
}>();

const { goTo } = useGasBillRechargeContext();

const { blLifeRecharge } = useLifeRechargeContext();

const { lifePayGasRate } = useGetRate();
const { gasParValueList } = useGetGasParValue();

const form = reactive({
  parValue: 0,
  // province: '',
  // city: '',
  gasOrgType: '',
  gasAccount: '',
  currentUserAccountId: '',
  remark: '',
  areaList: [] as string[],
  lifePayType: initLifePayType(props.isInWeChat, props.isInAlipay),
  name: '',
});

const { userAccountAllList, handleUserAccountChange } = useSetUserAccountBySelect({
  lifePayOrderType: LifeRechargeConstants.LifePayOrderTypeEnum.燃气订单,
  onSetUserAccount(currentUserAccount) {
    const currentUserAccountExtraProperties = JSON.parse(
      currentUserAccount.extraProperties
    ) as GasUserAccountExtraProperties;
    form.currentUserAccountId = currentUserAccount.id;
    form.gasAccount = currentUserAccount.content;
    form.areaList = [currentUserAccount.province, currentUserAccount.city];
    form.gasOrgType = currentUserAccount.operators;

    form.remark = currentUserAccount.remark;
    form.name = currentUserAccountExtraProperties.name ?? '';
    const gasParValueItem = gasParValueList.value.find((x) => x.gasOrgCode === form.gasOrgType);
    if (gasParValueItem && gasParValueItem.parValue.every((x) => Number(x) !== form.parValue)) {
      form.parValue = 0;
    }
  },
});

function handleAddUserAccount() {
  goTo('step1');
}

const currentGasParValueItem = computed(() =>
  gasParValueList.value.find((x) => x.gasOrgCode === form.gasOrgType)
);

const gasValueList = computed(() => {
  const gasValueList = currentGasParValueItem.value?.parValue ?? [];
  return blLifeRecharge.filterParValueList(gasValueList);
});

const realParValue = computed(() =>
  blLifeRecharge.getRechargeParValue(form.parValue, lifePayGasRate.value)
);
const discountParValue = computed(() => form.parValue - Number(realParValue.value));

const rules = reactive<FormRules>({
  parValue: [
    { required: true, message: '请选择充值金额', validator: FormValidator.validatorNumberNotNull },
  ],
  currentUserAccountId: [{ required: true, message: '请选择充值户号' }],
  lifePayType: [{ required: true, message: '请选择支付方式' }],
});

const formRef = ref<any>(null);

function handleSubmit() {
  if (!form.name) {
    state.show = true;
    state.msg = '请先完善所属户主姓名';
    return;
  }
  if (!formRef.value) return;
  formRef.value.validate().then(({ valid, errors }: any) => {
    if (valid) {
      recharge();
    }
  });
}

const confirmDialogVisible = ref(false);

function recharge() {
  confirmDialogVisible.value = true;
}

const { state, invokeAliPay, invokeWeixinPay } = useSelectPayType({
  getOpenId: props.getOpenId,
  isInWeChat: toRef(props, 'isInWeChat'),
  isH5: toRef(props, 'isH5'),
  appId: toRef(props, 'appId'),
});

const currentOrderNo = ref('');

async function goPay() {
  try {
    let params: LifeGasDataCreateLifePayOrderInput = {
      userId: blLifeRecharge.accountModel.userId,
      channelId: blLifeRecharge.accountModel.channlesNum,
      productData: {
        parValue: form.parValue,
        gasOrgType: form.gasOrgType,
        gasAccount: form.gasAccount,
        province: form.areaList?.[0] ?? '',
        city: form.areaList?.[1] ?? '',
        name: form.name,
      },
    };
    let res = await blLifeRecharge.services.createLifePayGasOrder(params);
    // emit('goPay', res.orderNo);
    if (form.lifePayType === LifeRechargeConstants.LifePayTypeEnum.WxPay) {
      await invokeWeixinPay(res.orderNo);
    } else {
      await invokeAliPay(res.orderNo);
    }
    currentOrderNo.value = res.orderNo;
  } catch (error) {}
}

useGetPayStatusByOrderNo({
  orderNo: currentOrderNo,
  enabled: computed(() => props.isFocus && !!currentOrderNo.value),
  onPaySuccess: (orderNo) => {
    emit('paySuccess', orderNo);
    currentOrderNo.value = '';
  },
});
</script>
